@@ -152,28 +152,24 @@ def _load_trinkets() -> typing.List[Trinket]:
                 item["ilevel"],
             ]
         if source == Source.PVP:
-            if "Aspirant" in item.get("name", None):
-                return list(
-                    [
-                        itemlevel
-                        for itemlevel in ItemLevel.PVP_HONOR
-                        if itemlevel >= item.get("ilevel", 0)
-                    ]
-                )
-            elif "Gladiator" in item.get("name", None):
-                return list(
-                    [
-                        itemlevel
-                        for itemlevel in ItemLevel.PVP_CONQUEST
-                        if itemlevel >= item.get("ilevel", 0)
-                    ]
-                )
+            if "Aspirant" in item["name"]:
+                return [
+                    itemlevel
+                    for itemlevel in ItemLevel.PVP_HONOR
+                    if itemlevel >= item.get("ilevel", 0)
+                ]
             else:
-                raise ValueError("What the fuck is going on.")
+                return [
+                    itemlevel
+                    for itemlevel in ItemLevel.PVP_CONQUEST
+                    if itemlevel >= item.get("ilevel", 0)
+                ]
         if source == Source.RARE_MOB:
             return ItemLevel.RARE_MOB.get(item["ilevel"], [item["ilevel"]])
+
         if source == Source.CALLING:
             return ItemLevel.CALLINGS
+
         return [
             item["ilevel"],
         ]
@@ -362,3 +358,20 @@ def get_versatility_trinket(stat: Stat) -> Trinket:
             on_use=False,
         )
     raise ValueError(f"Unknown stat {stat}. No Versatility trinket available.")
+
+
+def _get_trinket(id: int = None, name: str = None) -> Trinket:
+    if not (id or name):
+        raise ValueError("id or name must be provided to look up a trinket")
+
+    for trinket in TRINKETS:
+        if trinket.item_id == id or trinket.name == name:
+            return trinket
+    raise FileNotFoundError("Trinket not found")
+
+
+def get_trinket(search: typing.Union[int, str]) -> Trinket:
+    if isinstance(search, int):
+        return _get_trinket(id=search)
+    elif isinstance(search, str):
+        return _get_trinket(name=search)
